@@ -314,6 +314,7 @@ class Cursor(DBAPICursor):
         _logger.info("fetching all from overriden method")
         self._data = list()
         while len(self._data) < self.rowcount():
+            _logger.info("fetching next batch")
             rows = self.fetch_batch()
             self._data = self._data + rows
         return self._data
@@ -339,6 +340,7 @@ class Cursor(DBAPICursor):
         size = min(size, self.rowcount())
         self._data = list()
         while len(self._data) < size:
+            _logger.info("fetching next batch")
             rows = self.fetch_batch()
             self._data = self._data + rows
         return self._data if len(self._data) == size else self._data[0:size]
@@ -395,8 +397,8 @@ if __name__ == '__main__':
                          ssl_cert=None,
                          thrift_transport=None)
     cursor = Cursor(connection)
-    cursor.execute("select * from call_center;")
-    bdata = cursor.fetchmany(4)
+    cursor.execute("select * from date_dim;")
+    bdata = cursor.fetchone()
     try:
         # if len(bdata) < 1000:
         for row in bdata:
